@@ -1,4 +1,4 @@
-use futures::{stream, Stream, TryStream};
+use futures_util::{stream, Stream, TryStream};
 use reqwest::StatusCode;
 
 use crate::{
@@ -44,8 +44,8 @@ impl<'a> ObjectClient<'a> {
         let url = &format!(
             "{}/{}/o?uploadType=media&name={}",
             BASE_URL,
-            percent_encode(&bucket),
-            percent_encode(&filename),
+            percent_encode(bucket),
+            percent_encode(filename),
         );
         let mut headers = self.0.get_headers().await?;
         headers.insert(CONTENT_TYPE, mime_type.parse()?);
@@ -102,8 +102,8 @@ impl<'a> ObjectClient<'a> {
         let url = &format!(
             "{}/{}/o?uploadType=media&name={}",
             BASE_URL,
-            percent_encode(&bucket),
-            percent_encode(&filename),
+            percent_encode(bucket),
+            percent_encode(filename),
         );
         let mut headers = self.0.get_headers().await?;
         headers.insert(CONTENT_TYPE, mime_type.parse()?);
@@ -305,14 +305,14 @@ impl<'a> ObjectClient<'a> {
     /// use cloud_storage::Client;
     /// use cloud_storage::Object;
     /// use futures::StreamExt;
-    /// use std::fs::File;
-    /// use std::io::{BufWriter, Write};
+    /// use tokio::fs::File;
+    /// use tokio::io::{AsyncWriteExt, BufWriter};
     ///
     /// let client = Client::default();
     /// let mut stream = client.object().download_streamed("my_bucket", "path/to/my/file.png").await?;
-    /// let mut file = BufWriter::new(File::create("file.png").unwrap());
+    /// let mut file = BufWriter::new(File::create("file.png").await.unwrap());
     /// while let Some(byte) = stream.next().await {
-    ///     file.write_all(&[byte.unwrap()]).unwrap();
+    ///     file.write_all(&[byte.unwrap()]).await.unwrap();
     /// }
     /// # Ok(())
     /// # }
@@ -322,7 +322,7 @@ impl<'a> ObjectClient<'a> {
         bucket: &str,
         file_name: &str,
     ) -> crate::Result<impl Stream<Item = crate::Result<u8>> + Unpin> {
-        use futures::{StreamExt, TryStreamExt};
+        use futures_util::{StreamExt, TryStreamExt};
         let url = format!(
             "{}/b/{}/o/{}?alt=media",
             crate::BASE_URL,
@@ -340,7 +340,7 @@ impl<'a> ObjectClient<'a> {
         let size = response.content_length();
         let bytes = response
             .bytes_stream()
-            .map(|chunk| chunk.map(|c| futures::stream::iter(c.into_iter().map(Ok))))
+            .map(|chunk| chunk.map(|c| futures_util::stream::iter(c.into_iter().map(Ok))))
             .try_flatten();
         Ok(SizedByteStream::new(bytes, size))
     }
@@ -458,8 +458,8 @@ impl<'a> ObjectClient<'a> {
         let url = format!(
             "{}/b/{}/o/{}/compose",
             crate::BASE_URL,
-            percent_encode(&bucket),
-            percent_encode(&destination_object)
+            percent_encode(bucket),
+            percent_encode(destination_object)
         );
         let result: GoogleResponse<Object> = self
             .0
@@ -505,8 +505,8 @@ impl<'a> ObjectClient<'a> {
             base = crate::BASE_URL,
             sBucket = percent_encode(&object.bucket),
             sObject = percent_encode(&object.name),
-            dBucket = percent_encode(&destination_bucket),
-            dObject = percent_encode(&path),
+            dBucket = percent_encode(destination_bucket),
+            dObject = percent_encode(path),
         );
         let mut headers = self.0.get_headers().await?;
         headers.insert(CONTENT_LENGTH, "0".parse()?);
@@ -565,18 +565,21 @@ impl<'a> ObjectClient<'a> {
         );
         let mut headers = self.0.get_headers().await?;
         headers.insert(CONTENT_LENGTH, "0".parse()?);
-        let result: GoogleResponse<RewriteResponse> = self
+        let s = self
             .0
             .client
             .post(&url)
             .headers(headers)
             .send()
             .await?
-            .json()
+            .text()
             .await?;
-        match result {
-            GoogleResponse::Success(s) => Ok(s.resource),
-            GoogleResponse::Error(e) => Err(e.into()),
-        }
+
+        let result: RewriteResponse = serde_json::from_str(dbg!(&s)).unwrap();
+        Ok(result.resource)
+        // match result {
+        // GoogleResponse::Success(s) => Ok(s.resource),
+        // GoogleResponse::Error(e) => Err(e.into()),
+        // }
     }
 }
