@@ -1,8 +1,8 @@
 pub use crate::resources::bucket::Owner;
 use crate::resources::object_access_control::ObjectAccessControl;
-use futures::Stream;
+use futures_util::Stream;
 #[cfg(feature = "global-client")]
-use futures::TryStream;
+use futures_util::TryStream;
 use percent_encoding::{utf8_percent_encode, AsciiSet, NON_ALPHANUMERIC};
 use std::collections::HashMap;
 
@@ -227,11 +227,12 @@ pub struct ObjectList {
 
 #[derive(Debug, serde::Deserialize)]
 #[serde(rename_all = "camelCase")]
+#[allow(dead_code)]
 pub(crate) struct RewriteResponse {
-    pub(crate) kind: String,
-    pub(crate) total_bytes_rewritten: String,
-    pub(crate) object_size: String,
-    pub(crate) done: bool,
+    kind: String,
+    total_bytes_rewritten: String,
+    object_size: String,
+    done: bool,
     pub(crate) resource: Object,
 }
 
@@ -330,7 +331,7 @@ impl Object {
         file.read_to_end(&mut buffer)
             .map_err(|e| crate::Error::Other(e.to_string()))?;
 
-        let stream = futures::stream::once(async { Ok::<_, crate::Error>(buffer) });
+        let stream = futures_util::stream::once(async { Ok::<_, crate::Error>(buffer) });
 
         crate::runtime()?.block_on(Self::create_streamed(
             bucket, stream, length, filename, mime_type,
@@ -368,7 +369,7 @@ impl Object {
     /// This function requires that the feature flag `sync` is enabled in `Cargo.toml`.
     #[cfg(all(feature = "global-client", feature = "sync"))]
     pub fn list_sync(bucket: &str, list_request: ListRequest) -> crate::Result<Vec<ObjectList>> {
-        use futures::TryStreamExt;
+        use futures_util::TryStreamExt;
 
         let rt = crate::runtime()?;
         let listed = rt.block_on(Self::list(bucket, list_request))?;
@@ -754,8 +755,6 @@ impl Object {
         content_disposition: Option<String>,
         custom_metadata: &HashMap<String, String>,
     ) -> crate::Result<String> {
-        use openssl::sha;
-
         if duration > 604800 {
             let msg = format!(
                 "duration may not be greater than 604800, but was {}",
@@ -770,7 +769,7 @@ impl Object {
         for (k, v) in custom_metadata.iter() {
             headers.push((format!("x-goog-meta-{}", k.to_string()), v.to_string()));
         }
-        headers.sort_unstable_by(|(k1, _), (k2, _)| k1.cmp(&k2));
+        headers.sort_unstable_by(|(k1, _), (k2, _)| k1.cmp(k2));
         let canonical_headers: String = headers
             .iter()
             .map(|(k, v)| format!("{}:{}", k.to_lowercase(), v.to_lowercase()))
@@ -800,8 +799,7 @@ impl Object {
         );
 
         // 2 get hex encoded SHA256 hash the canonical request
-        let hash = sha::sha256(canonical_request.as_bytes());
-        let hex_hash = hex::encode(hash);
+        let hex_hash = hex::encode(crypto::sha256(canonical_request.as_bytes()).as_ref());
 
         // 3 construct the string to sign
         let string_to_sign = format!(
@@ -816,8 +814,7 @@ impl Object {
         );
 
         // 4 sign the string to sign with RSA - SHA256
-        let buffer = Self::sign_str(&string_to_sign)?;
-        let signature = hex::encode(&buffer);
+        let signature = hex::encode(crypto::rsa_pkcs1_sha256(&string_to_sign)?);
 
         // 5 construct the signed url
         Ok(format!(
@@ -899,9 +896,12 @@ impl Object {
     fn get_credential_scope(date: &chrono::DateTime<chrono::Utc>) -> String {
         format!("{}/henk/storage/goog4_request", date.format("%Y%m%d"))
     }
+}
 
+#[cfg(feature = "openssl")]
+mod openssl {
     #[inline(always)]
-    fn sign_str(message: &str) -> crate::Result<Vec<u8>> {
+    pub fn rsa_pkcs1_sha256(message: &str) -> crate::Result<Vec<u8>> {
         use openssl::{hash::MessageDigest, pkey::PKey, sign::Signer};
 
         let key = PKey::private_key_from_pem(crate::SERVICE_ACCOUNT.private_key.as_bytes())?;
@@ -909,6 +909,44 @@ impl Object {
         signer.update(message.as_bytes())?;
         Ok(signer.sign_to_vec()?)
     }
+
+    #[inline(always)]
+    pub fn sha256(bytes: &[u8]) -> impl AsRef<[u8]> {
+        openssl::sha::sha256(bytes)
+    }
+}
+
+#[cfg(feature = "ring")]
+mod ring {
+    #[cfg_attr(all(feature = "ring", feature = "openssl"), allow(dead_code))]
+    #[inline(always)]
+    pub fn rsa_pkcs1_sha256(message: &str) -> crate::Result<Vec<u8>> {
+        use ring::{
+            rand::SystemRandom,
+            signature::{RsaKeyPair, RSA_PKCS1_SHA256},
+        };
+
+        let key_pem = pem::parse(crate::SERVICE_ACCOUNT.private_key.as_bytes())?;
+        let key = RsaKeyPair::from_pkcs8(&key_pem.contents)?;
+        let rng = SystemRandom::new();
+        let mut signature = vec![0; key.public_modulus_len()];
+        key.sign(&RSA_PKCS1_SHA256, &rng, message.as_bytes(), &mut signature)?;
+        Ok(signature)
+    }
+
+    #[cfg_attr(all(feature = "ring", feature = "openssl"), allow(dead_code))]
+    #[inline(always)]
+    pub fn sha256(bytes: &[u8]) -> impl AsRef<[u8]> {
+        use ring::digest::{digest, SHA256};
+        digest(&SHA256, bytes)
+    }
+}
+
+mod crypto {
+    #[cfg(feature = "openssl")]
+    pub use super::openssl::*;
+    #[cfg(all(feature = "ring", not(feature = "openssl")))]
+    pub use super::ring::*;
 }
 
 const ENCODE_SET: &AsciiSet = &NON_ALPHANUMERIC
@@ -933,7 +971,7 @@ pub(crate) fn percent_encode(input: &str) -> String {
 mod tests {
     use super::*;
     use crate::Error;
-    use futures::{stream, StreamExt, TryStreamExt};
+    use futures_util::{stream, StreamExt, TryStreamExt};
 
     #[tokio::test]
     async fn create() -> Result<(), Box<dyn std::error::Error>> {
@@ -1242,6 +1280,20 @@ mod tests {
         Ok(())
     }
 
+    #[cfg(all(feature = "openssl", feature = "ring"))]
+    #[test]
+    fn check_matching_crypto() {
+        assert_eq!(
+            openssl::sha256(b"hello").as_ref(),
+            ring::sha256(b"hello").as_ref()
+        );
+
+        assert_eq!(
+            openssl::rsa_pkcs1_sha256("world").unwrap(),
+            ring::rsa_pkcs1_sha256("world").unwrap(),
+        );
+    }
+
     #[cfg(feature = "sync")]
     mod sync {
         use super::*;
@@ -1496,9 +1548,9 @@ impl<S: Stream<Item = crate::Result<u8>> + Unpin> Stream for SizedByteStream<S>
 
     fn poll_next(
         mut self: std::pin::Pin<&mut Self>,
-        cx: &mut futures::task::Context,
-    ) -> futures::task::Poll<Option<Self::Item>> {
-        futures::StreamExt::poll_next_unpin(&mut self.bytes, cx)
+        cx: &mut std::task::Context,
+    ) -> std::task::Poll<Option<Self::Item>> {
+        futures_util::StreamExt::poll_next_unpin(&mut self.bytes, cx)
     }
 
     fn size_hint(&self) -> (usize, Option<usize>) {
